@@ -93,17 +93,15 @@ class AlignmentParser:
 
         return attrs, src_id_set, trg_id_set
 
-    def collect_links(self, cur_pos=0):
+    def collect_links(self, cur_pos=0, verbose=False):
         """Collect links for a linkGrp"""
 
         attrs = []
         src_id_set, trg_id_set = set(), set()
         src_doc, trg_doc = None, None
 
-        slen = 0
-
         try:
-            blocks, slen = self.bp.get_complete_blocks(slen)
+            blocks, cur_pos = self.bp.get_complete_blocks(cur_pos, verbose)
             while blocks:
                 for block in blocks:
                     if block.name == 'link':
@@ -111,14 +109,11 @@ class AlignmentParser:
                     elif block.name == 'linkGrp':
                         src_doc = block.attributes['fromDoc']
                         trg_doc = block.attributes['toDoc']
-                        cur_pos += slen
-                        progress = str(round(cur_pos/self.af_size*100, 2))
-                        return attrs, src_id_set, trg_id_set, src_doc, trg_doc, progress, cur_pos
-                blocks, slen = self.bp.get_complete_blocks(slen)
+                        return attrs, src_id_set, trg_id_set, src_doc, trg_doc, cur_pos
+                blocks, cur_pos = self.bp.get_complete_blocks(cur_pos, verbose)
         except BlockParserError as e:
             raise AlignmentParserError(
                 'Error while parsing alignment file: {error}'.format(error=e.args[0]))
 
-        progress = str(round(self.alignment_file.tell()/self.af_size*100, 2))
-        return attrs, src_id_set, trg_id_set, src_doc, trg_doc, progress, cur_pos
+        return attrs, src_id_set, trg_id_set, src_doc, trg_doc, cur_pos
 
