@@ -55,6 +55,10 @@ class BlockParser:
         self.block = Block(name='root')
         self.completeBlocks = []
 
+        self.document.seek(0, 2)
+        self.doc_size = self.document.tell()
+        self.document.seek(0)
+
         def start_element(name, attrs):
             """Update current block"""
             sub_block = Block(parent=self.block, name=name, attributes=attrs)
@@ -89,21 +93,31 @@ class BlockParser:
     def close_document(self):
         self.document.close()
 
-    def get_complete_blocks(self, cur_pos):
+    def get_complete_blocks(self, cur_pos, verbose=False):
         """
         Read lines until one or more end tags are found on a single line,
         and return the block trees corresponding to those end tags.
 
         cur_pos -- Current position in file
+        verbose -- Print progress messages
         """
 
         for line in self.document:
+            if verbose:
+                if cur_pos%10000 == 0 or cur_pos == self.doc_size:
+                    progress = str(round(cur_pos/self.doc_size*100, 2))
+                    print("\x1b[2KParsing file \"{}\" ... {}%".format(self.document.name,
+                        progress), end="\r")
             cur_pos += len(line)
             self.parse_line(line)
             if len(self.completeBlocks) > 0:
                 ret_blocks = self.completeBlocks
                 self.completeBlocks = []
                 return ret_blocks, cur_pos
+        progress = str(round(cur_pos/self.doc_size*100, 2))
+        if verbose:
+            print("\x1b[2KParsing file \"{}\" ... {}%".format(self.document.name,
+                progress), end="\r")
         return None, None
 
     @staticmethod
